@@ -509,7 +509,7 @@ void KWordQuizApp::initView()
   connect(m_pageWidget, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)), this, SLOT(slotCurrentPageChanged(KPageWidgetItem*,KPageWidgetItem*)));
 
   QVBoxLayout *editorLayout = new QVBoxLayout();
-  editorLayout->setMargin(0);
+  editorLayout->setContentsMargins(0, 0, 0, 0);
 
   m_searchLine = new FilterProxySearchLine(this);
   m_searchLine->setFocusPolicy(Qt::ClickFocus);
@@ -878,8 +878,8 @@ bool KWordQuizApp::saveDocAsFileName(KEduVocDocument *document)
   int result = KEduVocDocument::Unknown;
 
   QString filter = KEduVocDocument::pattern(KEduVocDocument::Writing);
-  filter.append('\n');
-  filter.append(i18n("*.html|HTML Document"));
+  filter.append(QStringLiteral(";;"));
+  filter.append(i18n("HTML Document") + QStringLiteral(" (*.html)"));
 
   QPointer<QFileDialog> fd = new QFileDialog(this, i18n("Save Vocabulary Document As"), QString(), filter);
   fd->setAcceptMode(QFileDialog::AcceptSave);
